aboutsummaryrefslogtreecommitdiffstats
path: root/src/libserver/task.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/libserver/task.c')
-rw-r--r--src/libserver/task.c9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/libserver/task.c b/src/libserver/task.c
index 876ab51ca..4aa2e21ad 100644
--- a/src/libserver/task.c
+++ b/src/libserver/task.c
@@ -779,9 +779,14 @@ rspamd_task_process (struct rspamd_task *task, guint stages)
}
break;
- case RSPAMD_TASK_STAGE_DONE:
- /* Second run of composites processing */
+ case RSPAMD_TASK_STAGE_IDEMPOTENT:
+ /* Second run of composites processing before idempotent filters */
rspamd_make_composites (task);
+ rspamd_symbols_cache_process_symbols (task, task->cfg->cache,
+ RSPAMD_TASK_STAGE_IDEMPOTENT);
+ break;
+
+ case RSPAMD_TASK_STAGE_DONE:
task->processed_stages |= RSPAMD_TASK_STAGE_DONE;
break;